package com.capitalware.mqcm.handlers;

import java.util.StringTokenizer;

/**
 * This class will handle matching a channel name against a filter.
 * @author Roger Lacroix
 * @version 1.2
 * @license Apache 2 License
 */
public class ChannelNameFilter
{
   private String[]  prefix;
   private String[]  suffix;
   private boolean   acceptAll = false;
   private int       count = 1;

   /**
    * The constructor
    * @param chlNameFilter
    */
   public ChannelNameFilter(String chlNameFilter)
   {
      super();

      if ( "*".equals(chlNameFilter))
      {
         acceptAll = true;
         return;
      }

      /*
       * Break the user-defined filter string into individual filters
       */
      StringTokenizer bufferST = new StringTokenizer(chlNameFilter,";");

      count = bufferST.countTokens();

      prefix = new String[count];
      suffix = new String[count];

      for (int i=0; i < count; i++)
      {
         String filter = bufferST.nextToken();

         int x = filter.lastIndexOf('*');
         if ( x == 0)
         {
            prefix[i] = null;
            suffix[i] = filter.substring(1);
         }
         else if (x == -1)
         {
            prefix[i] = filter;
            suffix[i] = null;
         }
         else if (x == (filter.length() - 1))
         {
            prefix[i] = filter.substring(0,x);
            suffix[i] = null;
         }
         else
         {
            prefix[i] = filter.substring(0,x);
            suffix[i] = filter.substring(x+1);
         }
      }
   }

   /**
    * Filter the channel name
    *
    * @param chlName
    * @return true / false
    */
   public boolean accept(String chlName)
   {
      if (acceptAll)
         return true;

      for (int i=0; i < count; i++)
      {
         if ( (prefix[i] == null) && (chlName.endsWith(suffix[i])) )
            return true;
         else if ( (suffix[i] == null) && (chlName.startsWith(prefix[i])) )
            return true;
         else if ( (chlName.startsWith(prefix[i])) && (chlName.endsWith(suffix[i])) )
            return true;
      }

      return false;
   }

   /**
    * Retrieve the number of filers.
    * @return count
    */
   public int getFilterCount()
   {
      return count;
   }
}
