package com.capitalware.mqcm.objects;

import java.io.File;
import java.io.IOException;

import org.jdom.JDOMException;

import com.capitalware.mqcm.xml.MQXml;

/**
 * This class holds the MQ connection information.
 * @author Roger Lacroix, Capitalware Inc.
 * @version 1.2
 * @license Apache 2 License
 */
public class MQObject
{
   public String monitorChlName = "*";
   public int    refreshRate = 60;

   public String qMgrName = null;
   public String hostname = null;
   public String channelName = null;
   public int    port = -1;
   //
   public String userID = null;
   public String password = null;
   //
   public String securityExit = null;
   public String securityExitPath = null;
   //
   public String cipherSuiteName = null;
   public String distinguishedName = null;
   public String trustedStore = null;
   public String trustedStorePasswd = null;
   public String keyStore = null;
   public String keyStorePasswd = null;
   public String ldapServer = null;
   public int    ldapServerPort = -1;
   //
   public String CCDTFile = null;
   public String mqXmlFile = null;

   /*
    * The constructor
    */
   public MQObject(String mqXmlFile)
   {
      super();
      this.mqXmlFile = mqXmlFile;
   }

   /**
    *
    * @throws IOException
    * @throws JDOMException
    */
   public void checkQM() throws IOException, JDOMException
   {
      if (mqXmlFile != null)
      {
         MQXml mqp = new MQXml();
         mqp.readXMLFile(mqXmlFile);

         monitorChlName = mqp.getMonitorChannelName();
         refreshRate = mqp.getRefreshRate();

         qMgrName = mqp.getQMgrName();
         hostname = mqp.getHostname();
         channelName = mqp.getChannelName();
         port = mqp.getPort();
         //
         userID = mqp.getUserID();
         password = mqp.getPassword();
         //
         securityExit = mqp.getSecurityExit();
         securityExitPath = mqp.getSecurityExitPath();
         //
         cipherSuiteName = mqp.getCipherSuiteName();
         distinguishedName = mqp.getDistinguishedName();
         trustedStore = mqp.getTrustedStore();
         trustedStorePasswd = mqp.getTrustedStorePasswd();
         keyStore = mqp.getKeyStore();
         keyStorePasswd = mqp.getKeyStorePasswd();
         ldapServer = mqp.getLdapServer();
         ldapServerPort = mqp.getLdapServerPort();
         
         CCDTFile = mqp.getCCDTFile();
      }

      if ( ("".equals(monitorChlName)) || (monitorChlName == null) )
         throw new IllegalArgumentException("MonitorChannelName tag cannot be blank.");

      if ( ("".equals(qMgrName)) || (qMgrName == null) )
         throw new IllegalArgumentException("Missing a required XML tag: QMgrName within MQ");

      if ( (userID == null) && (password != null) )
         throw new IllegalArgumentException("Cannot have a Password without a UserID: UserID within MQ");

      if ((hostname != null) || (channelName != null) || (port != -1))
      {
         if (hostname == null)
            throw new IllegalArgumentException("Missing the XML tag: Hostname within MQ.");
         if (channelName == null)
            throw new IllegalArgumentException("Missing the XML tag: ChannelName within MQ.");
         if (port == -1)
            throw new IllegalArgumentException("Missing the XML tag: Port within MQ.");

         if (CCDTFile != null)
            throw new IllegalArgumentException("The user cannot specify both channelname/hostname/port and CCDTFile.  Please specify only one method of connecting to the remote queue manager.");
      }
      else if (CCDTFile != null)
      {
         boolean exists = (new File(CCDTFile)).exists();
         if ( !(exists) )
            throw new IllegalArgumentException("Error: The CCDT file does not exists : " + CCDTFile);
      }
   }
}
